import pandas as pd

from sklearn.base import TransformerMixin


class DFFeatureUnion(TransformerMixin):
    # FeatureUnion but for pandas DataFrames

    def __init__(self, transformer_list, _on=None):
        self.transformer_list = transformer_list
        self._on = _on

    def fit(self, X, y=None):
        for (name, t) in self.transformer_list:
            t.fit(X, y)
        return self

    def transform(self, X):
        # assumes X is a DataFrame
        Xts = [t.transform(X) for _, t in self.transformer_list]
        Xunion = reduce(lambda X1, X2: pd.merge(X1, X2, on=self._on, left_index=not self._on, right_index=not self._on), Xts)

        return Xunion



from setuptools import setup
from pip.req import parse_requirements

install_reqs = parse_requirements('requirements.txt', session='hack')
req = [str(ir.req) for ir in install_reqs]
setup(
    name='pandas-transformers',
    version='0.1',
	author = "Oguzhan Sagoglu",
	author_email = "alwaysprep@gmail.com",
	description = ("Use pandas dataframes in sklearn pipelines"),
	license = "MIT",
	keywords = "pandas sklearn pipeline transformers",
	packages=['pd_tran'],
	install_requires=req,
	python_requires=">=2.7, <3",
	classifiers=[
        "Development Status :: 1 - Planning",
        "Intended Audience :: Developers",
	    "Topic :: Software Development",
	    "Topic :: Scientific/Engineering",
        "License :: OSI Approved :: MIT License",
        "Programming Language :: Python :: 2.7"
    ]
)